@@ -1,5 +1,6 @@
 from dataquality.loggers.data_logger import (
     image_classification,
+    structured_classification,
     text_classification,
     text_multi_label,
     text_ner,
@@ -7,9 +8,10 @@ from dataquality.loggers.data_logger import (
 from dataquality.loggers.data_logger.base_data_logger import BaseGalileoDataLogger
 
 __all__ = [
+    "image_classification",
     "text_classification",
+    "structured_classification",
     "text_multi_label",
     "text_ner",
-    "image_classification",
     "BaseGalileoDataLogger",
 ]
