@@ -30,11 +30,13 @@ class Route(str, Enum):
     epochs = "epochs"
     summary = "insights/summary"
     groupby = "insights/groupby"
+    metrics = "metrics"
     distribution = "insights/distribution"
     xray = "insights/xray"
     export = "export"
     edits = "edits"
     export_edits = "edits/export"
+    upload_dataset = "upload_dataset"
     ampli = "ampli"
     notify = "notify/email"
     token = "get-token"
