@@ -99,10 +99,25 @@ def open_console_url(link: Optional[str] = "") -> None:
     if not link:
         return
     try:
-
         webbrowser.open(link)
     # In some environments, webbrowser will raise. Other times it fails silently (colab)
     except Exception:
         pass
     finally:
         print(f"Click here to see your run! {link}")
+
+
+def gpu_available() -> bool:
+    import torch
+
+    return torch.cuda.is_available()
+
+
+def mps_available() -> bool:
+    """Checks for an MPS compatible GPU on Apple machines.
+
+    This will enabled Metal acceleration for model training when supported.
+    """
+    import torch
+
+    return torch.backends.mps.is_available()
