@@ -3,4 +3,4 @@
 pip install --upgrade pip
 pip install flit
 
-flit install --deps=all --extras=all --symlink
+flit install --deps=develop --symlink
