@@ -1,4 +1,5 @@
-from typing import Callable, Dict, Optional
+import os
+from typing import Callable, Dict, Generator, Optional
 from unittest import mock
 
 import numpy as np
@@ -11,6 +12,7 @@ import dataquality as dq
 from dataquality.clients.api import ApiClient
 from dataquality.clients.objectstore import ObjectStore
 from dataquality.exceptions import GalileoException
+from dataquality.loggers.base_logger import BaseGalileoLogger
 from dataquality.loggers.data_logger.structured_classification import (
     StructuredClassificationDataLogger,
 )
@@ -63,8 +65,19 @@ class TestStructuredClassificationDataLogger:
         )
         logger.validate()
 
-    def validate_inputs(self, fit_xgboost: xgb.XGBClassifier, sc_data: Dict) -> None:
-        """Test that validate_inputs casts X and y to the correct types"""
+    @mock.patch.object(StructuredClassificationDataLogger, "set_probs")
+    def test_validate_inputs(
+        self,
+        mock_set_probs: mock.MagicMock,
+        fit_xgboost: xgb.XGBClassifier,
+        sc_data: Dict,
+    ) -> None:
+        """Test that validate_inputs casts X and y to the correct types
+
+        Also test that validate calls:
+        - set probs
+        - save feature importances
+        """
         logger = StructuredClassificationDataLogger(
             model=fit_xgboost,
             X=sc_data["training"]["X"],
@@ -75,6 +88,9 @@ class TestStructuredClassificationDataLogger:
         logger.validate_and_prepare_logger()
         assert isinstance(logger.X, pd.DataFrame)
         assert isinstance(logger.y, np.ndarray)
+        assert logger.logger_config.feature_importances is not None
+
+        mock_set_probs.assert_called_once_with()
 
     def test_set_probs(self, fit_xgboost: xgb.XGBClassifier, sc_data: Dict) -> None:
         logger = StructuredClassificationDataLogger(
@@ -89,16 +105,54 @@ class TestStructuredClassificationDataLogger:
         # 3 since wine dataset has 3 classes
         assert logger.probs.shape == (len(logger.X), 3)
 
-    @mock.patch.object(ObjectStore, "create_project_run_object_from_df")
-    @mock.patch.object(StructuredClassificationDataLogger, "_get_dfs")
-    @mock.patch.object(StructuredClassificationDataLogger, "validate")
-    @mock.patch.object(StructuredClassificationDataLogger, "set_probs")
+    @mock.patch.object(ApiClient, "set_metric_for_run")
+    def test_save_feature_importances(
+        self,
+        mock_set_metrics: mock.MagicMock,
+        fit_xgboost: xgb.XGBClassifier,
+        sc_data: Dict,
+        set_test_config: Callable,
+    ) -> None:
+        set_test_config(task_type="structured_classification")
+        logger = StructuredClassificationDataLogger(
+            model=fit_xgboost,
+            X=sc_data["training"]["X"],
+            y=sc_data["training"]["y"],
+            feature_names=sc_data["feature_names"],
+            split="training",
+        )
+        # We need to call this to set logger config feature importances
+        logger.validate_and_prepare_logger()
+        logger.save_feature_importances()
+        mock_set_metrics.assert_called_once_with(
+            DEFAULT_PROJECT_ID,
+            DEFAULT_RUN_ID,
+            data={
+                "key": "feature_importances",
+                "value": 0,
+                "epoch": 0,
+                "extra": {
+                    "feature_0": mock.ANY,
+                    "feature_1": mock.ANY,
+                    "feature_2": mock.ANY,
+                    "feature_3": mock.ANY,
+                    "feature_4": mock.ANY,
+                    "feature_5": mock.ANY,
+                    "feature_6": mock.ANY,
+                    "feature_7": mock.ANY,
+                    "feature_8": mock.ANY,
+                    "feature_9": mock.ANY,
+                    "feature_10": mock.ANY,
+                    "feature_11": mock.ANY,
+                    "feature_12": mock.ANY,
+                },
+            },
+        )
+
+    @mock.patch.object(StructuredClassificationDataLogger, "save_feature_importances")
     def test_log(
         self,
-        mock_set_probs: mock.MagicMock,
-        mock_validate: mock.MagicMock,
-        mock_get_dfs: mock.MagicMock,
-        mock_upload_df_to_minio: mock.MagicMock,
+        mock_save_feature_importances: mock.MagicMock,
         set_test_config: Callable,
         create_logger: Callable,
     ) -> None:
@@ -107,40 +161,90 @@ class TestStructuredClassificationDataLogger:
         Very simple test that mocks all helper fns and makes sure they are called
         """
         set_test_config()
-        mock_get_dfs.return_value = (mock.MagicMock(), mock.MagicMock())
 
         logger: StructuredClassificationDataLogger = create_logger(split="training")
+        logger.validate_and_prepare_logger()
         logger.log()
 
-        mock_set_probs.assert_called_once_with()
-        mock_validate.assert_called_once_with()
-
-        mock_get_dfs.assert_called_once_with()
-        assert mock_upload_df_to_minio.call_count == 2
-        mock_upload_df_to_minio.assert_any_call(
-            mock.ANY, f"{DEFAULT_PROJECT_ID}/{DEFAULT_RUN_ID}/training/data/data.hdf5"
-        )
-        mock_upload_df_to_minio.assert_any_call(
-            mock.ANY, f"{DEFAULT_PROJECT_ID}/{DEFAULT_RUN_ID}/training/prob/prob.hdf5"
+        df_export_path = (
+            f"{BaseGalileoLogger.LOG_FILE_DIR}/{DEFAULT_PROJECT_ID}/{DEFAULT_RUN_ID}"
+            "/training"
         )
+        assert os.path.exists(f"{df_export_path}/data/data.hdf5")
+        assert os.path.exists(f"{df_export_path}/prob/prob.hdf5")
 
-    def test_get_dfs(self, create_logger: Callable, sc_data: Dict) -> None:
+    @mock.patch.object(StructuredClassificationDataLogger, "save_feature_importances")
+    def test_get_dfs(
+        self,
+        mock_save_feature_importances: mock.MagicMock,
+        create_logger: Callable,
+        sc_data: Dict,
+    ) -> None:
         # Set up logger with dataset, probs and split
         logger: StructuredClassificationDataLogger = create_logger(split="training")
         logger.validate_and_prepare_logger()
 
-        # Assertions on returned dfs
-        df, probs_df = logger._get_dfs()
+        df, prob_df = logger._get_dfs()
+
         assert isinstance(df, DataFrame)
         expected_cols = sc_data["feature_names"].copy()
-        expected_cols += ["id", "split", "data_schema_version"]
+        expected_cols += ["pred", "id", "split", "data_schema_version"]
         assert sorted(df.get_column_names()) == sorted(expected_cols)
 
-        assert isinstance(probs_df, DataFrame)
+        assert isinstance(prob_df, DataFrame)
         expected_cols = ["prob", "id", "gold"]
-        assert sorted(probs_df.get_column_names()) == sorted(expected_cols)
+        assert sorted(prob_df.get_column_names()) == sorted(expected_cols)
 
-        assert len(df) == len(probs_df)
+        # All dfs should have same number of rows
+        assert len(df) == len(prob_df)
+
+    @mock.patch.object(StructuredClassificationDataLogger, "save_feature_importances")
+    @mock.patch("dataquality.loggers.data_logger.structured_classification.os.walk")
+    @mock.patch.object(ObjectStore, "create_object")
+    def test_upload(
+        self,
+        mock_create_object: mock.MagicMock,
+        mock_os_walk: mock.MagicMock,
+        mock_save_importances: mock.MagicMock,
+        create_logger: Callable,
+    ) -> None:
+        """Test upload uploads to Minio"""
+        prefix = (
+            f"{BaseGalileoLogger.LOG_FILE_DIR}/{DEFAULT_PROJECT_ID}/{DEFAULT_RUN_ID}"
+        )
+        mock_os_walk.return_value = [
+            (
+                f"{prefix}/training/data",
+                [],
+                ["data.hdf5"],
+            ),
+            (
+                f"{prefix}/training/prob",
+                [],
+                ["prob.hdf5"],
+            ),
+        ]
+        logger: StructuredClassificationDataLogger = create_logger(split="training")
+        logger.upload()
+
+        assert mock_create_object.call_count == 2
+        prefix = (
+            f"{BaseGalileoLogger.LOG_FILE_DIR}/{DEFAULT_PROJECT_ID}/{DEFAULT_RUN_ID}"
+            "/training"
+        )
+        mock_create_object.assert_any_call(
+            object_name=(
+                f"{DEFAULT_PROJECT_ID}/{DEFAULT_RUN_ID}/training/data/data.hdf5"
+            ),
+            file_path=f"{prefix}/data/data.hdf5",
+        )
+        mock_create_object.assert_any_call(
+            object_name=(
+                f"{DEFAULT_PROJECT_ID}/{DEFAULT_RUN_ID}/training/prob/prob.hdf5"
+            ),
+            file_path=f"{prefix}/prob/prob.hdf5",
+        )
+        mock_save_importances.assert_called_once_with()
 
 
 class TestStructuredClassificationValidationErrors:
@@ -190,10 +294,7 @@ class TestStructuredClassificationValidationErrors:
         with pytest.raises(AssertionError) as e:
             logger.validate_and_prepare_logger()
 
-        assert str(e.value) == (
-            "Model must have a predict_proba method. "
-            "If you are using a custom model, please implement a predict_proba method."
-        )
+        assert str(e.value) == "Model must be included to log data."
 
     def test_validate_inputs_model_not_fitted(self) -> None:
         """Test error is raised if model is not already fit"""
@@ -298,14 +399,51 @@ class TestStructuredClassificationValidationErrors:
             "X and feature_names must have the same number of features"
         )
 
+    @pytest.mark.parametrize(
+        "name,badchars",
+        [
+            ("test!", "['!']"),
+            ("feature/name", "['/']"),
+            ("this,should,fail", "[',', ',']"),
+        ],
+    )
+    def test_validate_inputs_bad_feature_name(
+        self,
+        name: str,
+        badchars: str,
+        fit_xgboost: xgb.XGBClassifier,
+        sc_data: Dict,
+        set_test_config: Callable,
+        cleanup_after_use: Generator,
+    ) -> None:
+        """Test that validate_inputs casts X and y to the correct types"""
+        set_test_config()
+        feature_names = sc_data["feature_names"].copy()
+        feature_names[0] = name
+        logger = StructuredClassificationDataLogger(
+            model=fit_xgboost,
+            X=sc_data["training"]["X"],
+            y=list(sc_data["training"]["y"]),
+            feature_names=feature_names,
+            split="training",
+        )
+        with pytest.raises(GalileoException) as e:
+            logger.validate_and_prepare_logger()
 
-@mock.patch.object(ObjectStore, "create_project_run_object_from_df")
+        assert str(e.value) == (
+            "Only letters, numbers, whitespace, - and _ are allowed in a project "
+            f"or run name. Remove the following characters: {badchars}"
+        )
+
+
+@mock.patch.object(ObjectStore, "create_object")
 @mock.patch("dataquality.core.finish._version_check")
 @mock.patch("dataquality.core.finish._reset_run")
 @mock.patch("dataquality.core.finish.upload_dq_log_file")
 @mock.patch.object(
     ApiClient, "make_request", return_value={"link": "link", "job_name": "job_name"}
 )
+@mock.patch.object(StructuredClassificationDataLogger, "save_feature_importances")
 class TestStructuredClassificationE2E:
     def _assert_mocks(
         self,
@@ -314,8 +452,8 @@ class TestStructuredClassificationE2E:
         mock_version_check: mock.MagicMock,
         inf_only: bool = False,
     ) -> None:
-        mock_version_check.assert_called_once_with()
         mock_upload_dq_log_file.assert_called_once_with()
+        mock_version_check.assert_called_once_with()
         if inf_only:
             mock_reset_run.assert_not_called()
         else:
@@ -325,6 +463,7 @@ class TestStructuredClassificationE2E:
 
     def test_log_pandas_e2e(
         self,
+        mock_save_feature_importances: mock.MagicMock,
         mock_create_job: mock.MagicMock,
         mock_upload_dq_log_file: mock.MagicMock,
         mock_reset_run: mock.MagicMock,
@@ -351,8 +490,9 @@ class TestStructuredClassificationE2E:
         )
         dq.finish(wait=False)
 
-        # We upload df and probs_df for each split (training and test)
+        # We upload df and prob_df for each split (training and test)
         assert mock_upload_df_to_minio.call_count == 4
+        assert mock_save_feature_importances.call_count == 1
         mock_create_job.assert_called_once_with(
             RequestType.POST,
             url="http://localhost:8088/jobs",
@@ -363,12 +503,14 @@ class TestStructuredClassificationE2E:
                 "task_type": "structured_classification",
                 "tasks": None,
                 "ner_labels": [],
+                "feature_names": sc_data["feature_names"],
             },
         )
         self._assert_mocks(mock_upload_dq_log_file, mock_reset_run, mock_version_check)
 
     def test_log_arrays_e2e(
         self,
+        mock_save_feature_importances: mock.MagicMock,
         mock_create_job: mock.MagicMock,
         mock_upload_dq_log_file: mock.MagicMock,
         mock_reset_run: mock.MagicMock,
@@ -397,8 +539,9 @@ class TestStructuredClassificationE2E:
         )
         dq.finish(wait=False)
 
-        # We upload df and probs_df for each split (training and test)
+        # We upload df and prob_df for each split (training and test)
         assert mock_upload_df_to_minio.call_count == 4
+        assert mock_save_feature_importances.call_count == 1
         mock_create_job.assert_called_once_with(
             RequestType.POST,
             url="http://localhost:8088/jobs",
@@ -409,12 +552,14 @@ class TestStructuredClassificationE2E:
                 "task_type": "structured_classification",
                 "tasks": None,
                 "ner_labels": [],
+                "feature_names": sc_data["feature_names"],
             },
         )
         self._assert_mocks(mock_upload_dq_log_file, mock_reset_run, mock_version_check)
 
     def test_log_pandas_e2e_inference(
         self,
+        mock_save_feature_importances: mock.MagicMock,
         mock_create_job: mock.MagicMock,
         mock_upload_dq_log_file: mock.MagicMock,
         mock_reset_run: mock.MagicMock,
@@ -447,8 +592,9 @@ class TestStructuredClassificationE2E:
         )
         dq.finish(wait=False)
 
-        # We upload df and probs_df for each split (training and 2 inf)
+        # We upload df and prob_df for each split (training and 2 inf)
         assert mock_upload_df_to_minio.call_count == 6
+        assert mock_save_feature_importances.call_count == 1
         mock_create_job.assert_called_once_with(
             RequestType.POST,
             url="http://localhost:8088/jobs",
@@ -461,12 +607,14 @@ class TestStructuredClassificationE2E:
                 "ner_labels": [],
                 "job_name": JobName.inference,
                 "non_inference_logged": True,
+                "feature_names": sc_data["feature_names"],
             },
         )
         self._assert_mocks(mock_upload_dq_log_file, mock_reset_run, mock_version_check)
 
     def test_log_arrays_e2e_inference(
         self,
+        mock_save_feature_importances: mock.MagicMock,
         mock_create_job: mock.MagicMock,
         mock_upload_dq_log_file: mock.MagicMock,
         mock_reset_run: mock.MagicMock,
@@ -502,8 +650,9 @@ class TestStructuredClassificationE2E:
         )
         dq.finish(wait=False)
 
-        # We upload df and probs_df for each split (training and 2 inf)
+        # We upload df and prob_df for each split (training and 2 inf)
         assert mock_upload_df_to_minio.call_count == 6
+        assert mock_save_feature_importances.call_count == 1
         mock_create_job.assert_called_once_with(
             RequestType.POST,
             url="http://localhost:8088/jobs",
@@ -516,12 +665,14 @@ class TestStructuredClassificationE2E:
                 "ner_labels": [],
                 "job_name": JobName.inference,
                 "non_inference_logged": True,
+                "feature_names": sc_data["feature_names"],
             },
         )
         self._assert_mocks(mock_upload_dq_log_file, mock_reset_run, mock_version_check)
 
     def test_log_pandas_e2e_inference_only(
         self,
+        mock_save_feature_importances: mock.MagicMock,
         mock_create_job: mock.MagicMock,
         mock_upload_dq_log_file: mock.MagicMock,
         mock_reset_run: mock.MagicMock,
@@ -548,8 +699,9 @@ class TestStructuredClassificationE2E:
         )
         dq.finish(wait=False)
 
-        # We upload df and probs_df for each split (2 inf)
+        # We upload df and prob_df for each split (2 inf)
         assert mock_upload_df_to_minio.call_count == 4
+        assert mock_save_feature_importances.call_count == 1
         mock_create_job.assert_called_once_with(
             RequestType.POST,
             url="http://localhost:8088/jobs",
@@ -562,14 +714,19 @@ class TestStructuredClassificationE2E:
                 "ner_labels": [],
                 "job_name": JobName.inference,
                 "non_inference_logged": False,
+                "feature_names": sc_data["feature_names"],
             },
         )
         self._assert_mocks(
-            mock_upload_dq_log_file, mock_reset_run, mock_version_check, True
+            mock_upload_dq_log_file,
+            mock_reset_run,
+            mock_version_check,
+            True,
         )
 
     def test_log_arrays_e2e_inference_only(
         self,
+        mock_save_feature_importances: mock.MagicMock,
         mock_create_job: mock.MagicMock,
         mock_upload_dq_log_file: mock.MagicMock,
         mock_reset_run: mock.MagicMock,
@@ -598,8 +755,9 @@ class TestStructuredClassificationE2E:
         )
         dq.finish(wait=False)
 
-        # We upload df and probs_df for each split (2 inf)
+        # We upload df and prob_df for each split (2 inf)
         assert mock_upload_df_to_minio.call_count == 4
+        assert mock_save_feature_importances.call_count == 1
         mock_create_job.assert_called_once_with(
             RequestType.POST,
             url="http://localhost:8088/jobs",
@@ -612,8 +770,12 @@ class TestStructuredClassificationE2E:
                 "ner_labels": [],
                 "job_name": JobName.inference,
                 "non_inference_logged": False,
+                "feature_names": sc_data["feature_names"],
             },
         )
         self._assert_mocks(
-            mock_upload_dq_log_file, mock_reset_run, mock_version_check, True
+            mock_upload_dq_log_file,
+            mock_reset_run,
+            mock_version_check,
+            True,
         )
